#!/usr/bin/env bash

#################################################
#
# Script is used to create binary slices for 
# FireworkVideo and produces an  xcframework
# product. 
# 
# USAGE:
#  create_xcframework.sh [OUTPUT_PATH]
#
# An Output path is optional. The default value
# is the working directory.
# 
#################################################
SCRIPT_DIR=$(dirname "$0")
SCRIPT_DIR=$(cd $SCRIPT_DIR; pwd)
echo "SCRIPT_DIR: $SCRIPT_DIR"

ROOT_PROJECT_DIR=$(cd "$SCRIPT_DIR/../../.."; pwd)
echo "ROOT_PROJECT_DIR: $ROOT_PROJECT_DIR"

echo -n "working directory is "
pwd

WORKSPACE="FireworkVideoUI.xcworkspace"
ARTIFACT_NAME="FireworkVideoUI"
SCHEME="FireworkVideoUI"

WORKING_DIR="build"

FRAMEWORK_NAME="$ARTIFACT_NAME.framework"
XCFRAMEWORK_NAME="$ARTIFACT_NAME.xcframework"

SIM_ARCHIVE_PATH="$WORKING_DIR/$ARTIFACT_NAME-simulator"
IOS_ARCHIVE_PATH="$WORKING_DIR/$ARTIFACT_NAME-ios"

SIM_ARCHIVE="$SIM_ARCHIVE_PATH.xcarchive"
IOS_ARCHIVE="$IOS_ARCHIVE_PATH.xcarchive"

SIM_FRAMEWORK_PATH="$SIM_ARCHIVE/Products/Library/Frameworks/$FRAMEWORK_NAME"
IOS_FRAMEWORK_PATH="$IOS_ARCHIVE/Products/Library/Frameworks/$FRAMEWORK_NAME"

SIM_DSYM_PATH="$SIM_ARCHIVE/dSYMs/$FRAMEWORK_NAME.dSYM"
IOS_DSYM_PATH="$IOS_ARCHIVE/dSYMs/$FRAMEWORK_NAME.dSYM"

DSYM_OUTPUT="dSYMs"
SIM_DSYM_OUTPUT="$DSYM_OUTPUT/simulator"
IOS_DSYM_OUTPUT="$DSYM_OUTPUT/ios"

OUTPUT=$ROOT_PROJECT_DIR
XCODEBUILD_LOGGING=""
BUILD_NUMBER="1"

DEPENDENCY_VERSION=$(cat "$ROOT_PROJECT_DIR/react-native-firework-sdk.podspec" | grep "s.dependency 'FireworkVideo'" | awk -F ", " '{print $2}' | sed "s/'//g")
FRAMEWORK_VERSION=$DEPENDENCY_VERSION
while getopts ":o:qv:b:zi" opt; do
  case $opt in
    o)
      OUTPUT=$OPTARG
      ;;
    i)
      INCLUDE_DSYMS="TRUE"
      ;;
    q)
      XCODEBUILD_LOGGING="-quiet"
      ;;
    v)
      FRAMEWORK_VERSION=$OPTARG
      ;;
    b)
      BUILD_NUMBER=$OPTARG
      ;;
    z)
      SHOULD_COMPRESS="TRUE"
      ;;
    \?)
      echo "Invalid option: -$OPTARG" >&2
      exit 1
      ;;
    :)
      echo "Option -$OPTARG requires an argument." >&2
      exit 1
      ;;
  esac
done

rm -rf $OUTPUT/$XCFRAMEWORK_NAME

if [ -z "${FRAMEWORK_VERSION}" ]; then

echo "No version passed in deriving from git tag"
FRAMEWORK_VERSION="$(git describe HEAD --abbrev=0 --tags)"

fi

FRAMEWORK_VERSION="$(echo "$FRAMEWORK_VERSION" | grep -Eo '[0-9]+.[0-9]+.[0-9]+')"

echo "FRAMEWORK_VERSION : $FRAMEWORK_VERSION"
# Clean

echo "Cleaning working directory: $WORKING_DIR"
rm -rf $WORKING_DIR

pod install

# Archive slices

echo "Archiving Simulator"
xcodebuild archive \
     -workspace $WORKSPACE\
     -scheme $SCHEME \
     -destination "generic/platform=iOS Simulator" \
       -archivePath $SIM_ARCHIVE_PATH \
     SKIP_INSTALL=NO \
     BUILD_LIBRARY_FOR_DISTRIBUTION=YES \
       CURRENT_PROJECT_VERSION="$BUILD_NUMBER" \
       MARKETING_VERSION="$FRAMEWORK_VERSION" \
       $XCODEBUILD_LOGGING

echo "Archiving iOS Device"
xcodebuild archive \
     -workspace $WORKSPACE\
     -scheme $SCHEME \
     -destination generic/platform=iOS \
       -archivePath $IOS_ARCHIVE_PATH \
     SKIP_INSTALL=NO \
     BUILD_LIBRARY_FOR_DISTRIBUTION=YES \
       CURRENT_PROJECT_VERSION="$BUILD_NUMBER" \
       MARKETING_VERSION="$FRAMEWORK_VERSION" \
       $XCODEBUILD_LOGGING

# Create XCFramework

echo "Creating XCFramework"
xcodebuild -create-xcframework \
           -framework $SIM_FRAMEWORK_PATH \
           -framework $IOS_FRAMEWORK_PATH \
           -output $OUTPUT/$XCFRAMEWORK_NAME

if [ "$SHOULD_COMPRESS" = "TRUE" ]; then

# Compress Artifact

echo "Compressing framework"

cd $OUTPUT

zip -r $XCFRAMEWORK_NAME.zip $XCFRAMEWORK_NAME

cd -

fi


if [ "$INCLUDE_DSYMS" = "TRUE" ]; then

# Bundle dSym

cd $OUTPUT

echo "Bundling dSYMs"

mkdir -p $SIM_DSYM_OUTPUT
mkdir -p $IOS_DSYM_OUTPUT

mv ../$SIM_DSYM_PATH $SIM_DSYM_OUTPUT 
mv ../$IOS_DSYM_PATH $IOS_DSYM_OUTPUT 

zip -r $DSYM_OUTPUT.zip $DSYM_OUTPUT

cd -

fi
